==> gnome-utils-2.13.4.tar.bz2: gnome-utils-2.13.4/gnome-dictionary/src/gdict-pref-dialog.h <==
/* gdict-pref-dialog.h - preferences dialog
 *
 * This file is part of GNOME Dictionary
 *
 * Copyright (C) 2005 Emmanuele Bassi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef __GDICT_PREF_DIALOG_H__
#define __GDICT_PREF_DIALOG_H__

#include <gtk/gtk.h>

#include "gdict.h"

G_BEGIN_DECLS

#define GDICT_TYPE_PREF_DIALOG		(gdict_pref_dialog_get_type ())
#define GDICT_PREF_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GDICT_TYPE_PREF_DIALOG, GdictPrefDialog))
#define GDICT_IS_PREF_DIALOG(obj)	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GDICT_TYPE_PREF_DIALOG))

#define GDICT_DEFAULT_PRINT_FONT 	"Serif 10"
#define GDICT_DEFAULT_SOURCE_NAME 	"Default"

#define GDICT_GCONF_DIR	  		"/apps/gnome-dictionary"
#define GDICT_GCONF_DATABASE_KEY 	GDICT_GCONF_DIR "/database"
#define GDICT_GCONF_STRATEGY_KEY 	GDICT_GCONF_DIR "/strategy"
#define GDICT_GCONF_PRINT_FONT_KEY 	GDICT_GCONF_DIR "/print-font"
#define GDICT_GCONF_SOURCE_KEY 		GDICT_GCONF_DIR "/source-name"


typedef struct _GdictPrefDialog        GdictPrefDialog;
typedef struct _GdictPrefDialogClass   GdictPrefDialogClass;

GType      gdict_pref_dialog_get_type   (void) G_GNUC_CONST;
GtkWidget *gdict_pref_dialog_new        (GtkWindow         *parent,
				         const gchar       *title,
				         GdictSourceLoader *loader);

G_END_DECLS

#endif /* __GDICT_PREF_DIALOG_H__ */

==> gnome-utils-2.15.3.tar.bz2: gnome-utils-2.15.3/gnome-dictionary/src/gdict-pref-dialog.h <==
/* gdict-pref-dialog.h - preferences dialog
 *
 * This file is part of GNOME Dictionary
 *
 * Copyright (C) 2005 Emmanuele Bassi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#ifndef __GDICT_PREF_DIALOG_H__
#define __GDICT_PREF_DIALOG_H__

#include <gtk/gtk.h>
#include <libgdict/gdict.h>

G_BEGIN_DECLS

#define GDICT_TYPE_PREF_DIALOG		(gdict_pref_dialog_get_type ())
#define GDICT_PREF_DIALOG(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), GDICT_TYPE_PREF_DIALOG, GdictPrefDialog))
#define GDICT_IS_PREF_DIALOG(obj)	(G_TYPE_CHECK_INSTANCE_TYPE ((obj), GDICT_TYPE_PREF_DIALOG))

#define GDICT_DEFAULT_DEFBOX_FONT 	"Sans 10"
#define GDICT_DEFAULT_PRINT_FONT 	"Serif 10"
#define GDICT_DEFAULT_SOURCE_NAME 	"Default"

#define GDICT_GCONF_DIR				"/apps/gnome-dictionary"
#define GDICT_GCONF_DATABASE_KEY 		GDICT_GCONF_DIR "/database"
#define GDICT_GCONF_STRATEGY_KEY 		GDICT_GCONF_DIR "/strategy"
#define GDICT_GCONF_PRINT_FONT_KEY 		GDICT_GCONF_DIR "/print-font"
#define GDICT_GCONF_SOURCE_KEY 			GDICT_GCONF_DIR "/source-name"
#define GDICT_GCONF_WINDOW_WIDTH_KEY 		GDICT_GCONF_DIR "/default-window-width"
#define GDICT_GCONF_WINDOW_HEIGHT_KEY 		GDICT_GCONF_DIR "/default-window-height"
#define GDICT_GCONF_WINDOW_IS_MAXIMIZED_KEY 	GDICT_GCONF_DIR "/window-is-maximized"
#define GDICT_GCONF_SPELLER_VISIBLE_KEY		GDICT_GCONF_DIR "/speller-visible"

#define DOCUMENT_FONT_KEY 			"/desktop/gnome/interface/document_font_name"

typedef struct _GdictPrefDialog        GdictPrefDialog;
typedef struct _GdictPrefDialogClass   GdictPrefDialogClass;

GType gdict_pref_dialog_get_type (void) G_GNUC_CONST;

void gdict_show_pref_dialog (GtkWindow         *parent,
			     const gchar       *title,
			     GdictSourceLoader *loader);

G_END_DECLS

#endif /* __GDICT_PREF_DIALOG_H__ */
